summaryrefslogtreecommitdiffstats
path: root/tests/auto/declarative/qmlvisual/tst_qmlvisual.cpp
diff options
context:
space:
mode:
authorAlan Alpert <alan.alpert@nokia.com>2010-11-25 05:33:13 (GMT)
committerAlan Alpert <alan.alpert@nokia.com>2010-11-25 05:33:13 (GMT)
commit852f4811453cb0b082748f2fcefac5898e603ab0 (patch)
tree3b42839d93e847ed5a046145ad0a34d24278f7f6 /tests/auto/declarative/qmlvisual/tst_qmlvisual.cpp
parentbb575d308350036eff913a6b61c680712613c540 (diff)
downloadQt-852f4811453cb0b082748f2fcefac5898e603ab0.zip
Qt-852f4811453cb0b082748f2fcefac5898e603ab0.tar.gz
Qt-852f4811453cb0b082748f2fcefac5898e603ab0.tar.bz2
Fixup visual tests on Mac
Disable sub-pixel antialiasing and skip text on 10.5
Diffstat (limited to 'tests/auto/declarative/qmlvisual/tst_qmlvisual.cpp')
-rw-r--r--tests/auto/declarative/qmlvisual/tst_qmlvisual.cpp8
1 files changed, 7 insertions, 1 deletions
diff --git a/tests/auto/declarative/qmlvisual/tst_qmlvisual.cpp b/tests/auto/declarative/qmlvisual/tst_qmlvisual.cpp
index 2a15102..18fbfca 100644
--- a/tests/auto/declarative/qmlvisual/tst_qmlvisual.cpp
+++ b/tests/auto/declarative/qmlvisual/tst_qmlvisual.cpp
@@ -105,10 +105,16 @@ void tst_qmlvisual::visual_data()
files << findQmlFiles(QDir(QT_TEST_SOURCE_DIR));
if (qgetenv("QMLVISUAL_ALL") != "1") {
#if defined(Q_WS_X11)
//Text on X11 varies per distro - and the CI system is currently using something outdated.
foreach(const QString &str, files.filter(QRegExp(".*text.*")))
files.removeAll(str);
#endif
+#if defined(Q_WS_MAC)
+ //Text on Mac also varies per version. Only check the text on 10.6
+ if(QSysInfo::MacintoshVersion != QSysInfo::MV_10_6)
+ foreach(const QString &str, files.filter(QRegExp(".*text.*")))
+ files.removeAll(str);
+#endif
#if defined(Q_WS_QWS)
//We don't want QWS test results to mire down the CI system
files.clear();
@@ -105,10 +105,16 @@ void tst_qmlvisual::visual_data()
if (qgetenv("QMLVISUAL_ALL") != "1") {
#if defined(Q_WS_X11)
- //Text on X11 varies per distro - and the CI system is currently using something outdated.
+ //Text on X11 varies per version - and the CI system is currently using something outdated.
foreach(const QString &str, files.filter(QRegExp(".*text.*")))
files.removeAll(str);